@@ -189,3 +189,7 @@ def set_order(state):
                 state[state.manage_config.var_name_plural],
                 state.position_field
             )
+
+    flask.flash(
+        'Order of {0} updated'.format(state.manage_config.name_plural)
+    )
